#version 330

uniform sampler2D normalMap;
uniform float blendParam;
uniform bool hasNormalMap;

in vec2 vUv;
in vec3 fL;
in vec3 fH;
in vec3 vColor;

out vec4 finalColor;

void main()
{
    vec3 baseColor = vec3(0.5,0.5,0.5);
    vec3 color = mix(baseColor, vColor, blendParam);
    vec4 ambient, diffuse, specular;
    
    if (hasNormalMap) {
        ambient = vec4(color, 1.0);
        vec3 N = texture2D(normalMap, vUv).rgb;
        N = 2.0 * N - vec3(1.0, 1.0, 1.0);
        float Kd = max(dot(fL, N), 0.0);
        diffuse = Kd * vec4(color, 1.0);
        float Ks = pow(max(dot(N, fH), 0.0), 180.0);
        specular = Ks * vec4(1.0, 1.0, 1.0, 1.0);
    }
    else {
        ambient = vec4(0.0,0.0,0.0,1.0);
        diffuse = vec4(color,1.0);
        specular = vec4(0.0,0.0,0.0,0.0);
    }
    
    finalColor = (0.2 * ambient + 0.8 * diffuse + 0.0 * specular);
    finalColor.a = 1.0;
}